import { JobInfo } from './interfaces';
import Configuration from './Configuration';
import FileHandler from './FileUtils';
import moment from 'moment';
import { LoggerConfig } from './interfaces';
import S3Adapter from './storageAdapters/AmazonS3';
interface LogConfig {
    hoisted: boolean;
}
interface SaveConfig {
    saveAsNew?: boolean;
    clearLogsOnSave?: boolean;
}
declare enum LogTypes {
    INFO = "info",
    WARNING = "warning",
    ERROR = "error"
}
export declare class Logger {
    startTime: moment.Moment;
    endTime: moment.Moment;
    jobInfo: Configuration;
    logs: {
        info: any[];
        warning: any[];
        error: any[];
    };
    hoistedLogs: {
        info: any[];
        warning: any[];
        error: any[];
    };
    logFiles: {
        [key: string]: FileHandler;
    };
    loggerConfig: LoggerConfig;
    initialSaveDone: boolean;
    private adapter;
    constructor(jobInfo?: JobInfo, loggerConfig?: LoggerConfig);
    updateConfig(jobInfo: JobInfo, loggerConfig: LoggerConfig): void;
    setUpNewLogFileHandlers(): {
        info: FileHandler;
        warning: FileHandler;
        error: FileHandler;
    };
    useAdapter: (adapter: S3Adapter) => void;
    startLogTime: () => void;
    endLogTime: () => void;
    info: (message: any, config?: LogConfig) => void;
    warn: (message: any, config?: LogConfig) => void;
    error: (message: any, config?: LogConfig) => void;
    private storeLog;
    setJobStatus: (statusCode: number) => void;
    formatMessageByTag(message: string | {}, tag: string): string;
    getTaskDuration: () => moment.Duration;
    save: ({ saveAsNew, clearLogsOnSave }?: SaveConfig) => Promise<void>;
    clearLogFiles: () => void;
    clearLogs: () => void;
    private writeToAdapter;
    writeLogs: (logFiles: any) => void;
    writeJobInfo: (logFiles: {
        [key: string]: FileHandler;
    }) => void;
}
export default Logger;
